(Lazyearth) Library OOP for workwith odc

==============================================

โปรแกรมแชทนี้เป็นโปรแกรมที่เขียนขึ้นมาโดยใช้ Python โดยการเขียนแบบ OOP สำหรับใช้งานในการสร้าง class ต่างๆ อย่างรวดเร็ว เพียงแค่มี Python อยู่ในคอมพิวเตอร์ก็สามารถใช้งานได



ปล. เวอร์ชั่นนี้ยังไม่สมบูรณ์ (เขียนแบบรีบๆ) เขียนเพื่อนำ concept OOP มาสร้าง library แล้วก็ upload ขึ้น Github กับ PyPI ต่อไป สำหรับนักพัฒนาสามารถนำ Source Code ไปพัฒนาต่อได้เต็มที่ ซึ่งก็คืออีกโปรเจคนึ่งนั้นแหละ เพราะว่า jupyter มันไม่สามารถ import def ได้เหมือนกับตัว คอมก็เลยใช้วิธีนี้เอา และก็ยังมีอีกหลาย library ที่เขียนดองเอาไว้



Develop by : Tun Kedsaro 


